==> vlc-1.0.2.tar.bz2: vlc-1.0.2/modules/gui/qt4/components/playlist/playlist_item.hpp <==
/*****************************************************************************
 * playlist_item.hpp : Item for a playlist tree
 ****************************************************************************
 * Copyright (C) 2006 the VideoLAN team
 * $Id: c9d186b3b2307f18b0fc15e52cd27ad5b7bf7aeb $
 *
 * Authors: Clément Stenac <zorglub@videolan.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef _PLAYLIST_ITEM_H_
#define _PLAYLIST_ITEM_H_

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "components/playlist/playlist_model.hpp"

#include <QString>
#include <QList>

class QSettings;
class PLModel;

class PLItem
{
    friend class PLModel;
public:
    PLItem( int, int, bool, PLItem *parent , PLModel * );
    PLItem( playlist_item_t *, PLItem *parent, PLModel * );
    PLItem( playlist_item_t *, QSettings *, PLModel * );
    ~PLItem();

    int row() const;

    void insertChild( PLItem *, int p, bool signal = true );
    void appendChild( PLItem *item, bool signal = true )
    {
        insertChild( item, children.count(), signal );
    };

    void remove( PLItem *removed );

    PLItem *child( int row ) { return children.value( row ); };
    int childCount() const { return children.count(); };

    PLItem *parent() { return parentItem; };

    QString columnString( int col ) { return item_col_strings.value( col ); };

    void update( playlist_item_t *, bool );

protected:
    QList<PLItem*> children;
    QList<QString> item_col_strings;
    bool b_current;
    int i_type;
    int i_id;
    int i_input_id;
    int i_showflags;
    bool b_is_node;

private:
    void init( int, int, bool, PLItem *, PLModel *, QSettings * );
    void updateColumnHeaders();
    PLItem *parentItem;
    PLModel *model;
};

#endif

==> vlc_1.1.3.orig.tar.bz2: vlc-1.1.3/modules/gui/qt4/components/playlist/playlist_item.hpp <==
/*****************************************************************************
 * playlist_item.hpp : Item for a playlist tree
 ****************************************************************************
 * Copyright (C) 2006 the VideoLAN team
 * $Id: 6caafcb9a776558da0a208a05410e9b60b4f3042 $
 *
 * Authors: Clément Stenac <zorglub@videolan.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef _PLAYLIST_ITEM_H_
#define _PLAYLIST_ITEM_H_

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include <QList>


class PLItem
{
    friend class PLModel;
public:
    PLItem( playlist_item_t *, PLItem *parent );
    PLItem( playlist_item_t * );
    ~PLItem();

    int row() const;

    void insertChild( PLItem *, int p, bool signal = true );
    void appendChild( PLItem *item, bool signal = true )
    {
        children.insert( children.count(), item );
    };
    void removeChild( PLItem * );
    void removeChildren();
    void takeChildAt( int );

    PLItem *child( int row ) { return children.value( row ); }
    int childCount() const { return children.count(); }

    PLItem *parent() { return parentItem; }
    input_item_t *inputItem() { return p_input; }
    int id() { return i_id; }
    bool operator< ( PLItem& );

protected:
    QList<PLItem*> children;
    int i_id;
    input_item_t *p_input;

private:
    void init( playlist_item_t *, PLItem * );
    PLItem *parentItem;
};

#endif
